diff Framework/Toolbox/TextRenderer.h @ 1471:28c64c246312

working on a shared library
author Sebastien Jodogne <s.jodogne@gmail.com>
date Mon, 15 Jun 2020 12:57:54 +0200
parents 182bf3106ee2
children
line wrap: on
line diff
--- a/Framework/Toolbox/TextRenderer.h	Fri Jun 12 17:38:07 2020 +0200
+++ b/Framework/Toolbox/TextRenderer.h	Mon Jun 15 12:57:54 2020 +0200
@@ -22,7 +22,6 @@
 #pragma once
 
 #include <Images/Image.h>
-#include <EmbeddedResources.h>
 
 namespace OrthancStone
 {
@@ -33,18 +32,18 @@
   {
   public:
     // simply renders text in GrayScale8 with a black background and a white text
-    static Orthanc::ImageAccessor* Render(Orthanc::EmbeddedResources::FileResourceId resource,
+    static Orthanc::ImageAccessor* Render(const std::string& ttf,
                                           unsigned int fontSize,
                                           const std::string& utf8String);
 
     // renders text in "color" with alpha in a RGBA32 image
-    static Orthanc::ImageAccessor* RenderWithAlpha(Orthanc::EmbeddedResources::FileResourceId resource,
+    static Orthanc::ImageAccessor* RenderWithAlpha(const std::string& ttf,
                                                    unsigned int fontSize,
                                                    const std::string& utf8String,
                                                    uint8_t foreground);
 
     //    // renders text in color + a border with alpha in a RGBA32 image
     //    static Orthanc::ImageAccessor* RenderWithAlpha(Orthanc::EmbeddedResources::FileResourceId resource,
     //                                                   unsigned int fontSize,
     //                                                   const std::string& utf8String,
     //                                                   uint8_t foreground,
@@ -33,18 +32,18 @@
 
     //    // renders text in color + a border with alpha in a RGBA32 image
-    //    static Orthanc::ImageAccessor* RenderWithAlpha(Orthanc::EmbeddedResources::FileResourceId resource,
+    //    static Orthanc::ImageAccessor* RenderWithAlpha(const std::string& ttf,
     //                                                   unsigned int fontSize,
     //                                                   const std::string& utf8String,